#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class AnalysisSettingAtt(SettingController):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         AnalysisSettingAtt
                | 
                | Interface to handle parameters of DELMIA Analysis Tools Options Tab page Role:
                | This interface is implemented by a component which represents the controller of
                | Analysis Tools Options parameter settings.
                | 
                |     Methods to set value of each parameter
                |     Methods to get value of each parameter
                |     Methods to get information on each parameter
                |     Methods to lock/unlock value of each parameter
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.analysis_setting_att = com_object

    def get_analysis_level_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAnalysisLevelInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AnalysisLevel
                |     parameter.
                |     Role:Retrieves the state of the AnalysisLevel parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.analysis_setting_att.GetAnalysisLevelInfo(io_admin_level, io_locked)

    def get_anl_accel_limit_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAnlAccelLimitInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AnlAccelLimit
                |     parameter.
                |     Role:Retrieves the state of the AnlAccelLimit parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.analysis_setting_att.GetAnlAccelLimitInfo(io_admin_level, io_locked)

    def get_anl_caution_zone_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAnlCautionZoneInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AnlCautionZone
                |     parameter.
                |     Role:Retrieves the state of the AnlCautionZone parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.analysis_setting_att.GetAnlCautionZoneInfo(io_admin_level, io_locked)

    def get_anl_io_analysis_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAnlIOAnalysisInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AnlIOAnalysis
                |     parameter.
                |     Role:Retrieves the state of the AnlIOAnalysis parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.analysis_setting_att.GetAnlIOAnalysisInfo(io_admin_level, io_locked)

    def get_anl_int_dist_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAnlIntDistInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AnlIntDist
                |     parameter.
                |     Role:Retrieves the state of the AnlIntDist parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.analysis_setting_att.GetAnlIntDistInfo(io_admin_level, io_locked)

    def get_anl_intf_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAnlIntfInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AnlIntf
                |     parameter.
                |     Role:Retrieves the state of the AnlIntf parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.analysis_setting_att.GetAnlIntfInfo(io_admin_level, io_locked)

    def get_anl_lin_accel_limit_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAnlLinAccelLimitInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AnlLinAccelLimit
                |     parameter.
                |     Role:Retrieves the state of the AnlLinAccelLimit parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.analysis_setting_att.GetAnlLinAccelLimitInfo(io_admin_level, io_locked)

    def get_anl_lin_speed_limit_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAnlLinSpeedLimitInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AnlLinSpeedLimit
                |     parameter.
                |     Role:Retrieves the state of the AnlLinSpeedLimit parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.analysis_setting_att.GetAnlLinSpeedLimitInfo(io_admin_level, io_locked)

    def get_anl_measure_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAnlMeasureInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AnlMeasure
                |     parameter.
                |     Role:Retrieves the state of the AnlMeasure parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.analysis_setting_att.GetAnlMeasureInfo(io_admin_level, io_locked)

    def get_anl_rot_accel_limit_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAnlRotAccelLimitInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AnlRotAccelLimit
                |     parameter.
                |     Role:Retrieves the state of the AnlRotAccelLimit parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.analysis_setting_att.GetAnlRotAccelLimitInfo(io_admin_level, io_locked)

    def get_anl_rot_speed_limit_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAnlRotSpeedLimitInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AnlRotSpeedLimit
                |     parameter.
                |     Role:Retrieves the state of the AnlRotSpeedLimit parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.analysis_setting_att.GetAnlRotSpeedLimitInfo(io_admin_level, io_locked)

    def get_anl_travel_limit_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAnlTravelLimitInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AnlTravelLimit
                |     parameter.
                |     Role:Retrieves the state of the AnlTravelLimit parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.analysis_setting_att.GetAnlTravelLimitInfo(io_admin_level, io_locked)

    def get_anl_velocity_limit_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAnlVelocityLimitInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AnlVelocityLimit
                |     parameter.
                |     Role:Retrieves the state of the AnlVelocityLimit parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.analysis_setting_att.GetAnlVelocityLimitInfo(io_admin_level, io_locked)

    def get_ask_anl_mode_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAskAnlModeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AskAnlMode
                |     parameter.
                |     Role:Retrieves the state of the AskAnlMode parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.analysis_setting_att.GetAskAnlModeInfo(io_admin_level, io_locked)

    def get_beep_mode_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetBeepModeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the BeepMode
                |     parameter.
                |     Role:Retrieves the state of the BeepMode parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.analysis_setting_att.GetBeepModeInfo(io_admin_level, io_locked)

    def get_clash_colour_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetClashColorInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ClashColor
                |     parameter.
                |     Role:Retrieves the state of the ClashColor parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.analysis_setting_att.GetClashColorInfo(io_admin_level, io_locked)

    def get_clearance_colour_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetClearanceColorInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ClearanceColor
                |     parameter.
                |     Role:Retrieves the state of the ClearanceColor parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.analysis_setting_att.GetClearanceColorInfo(io_admin_level, io_locked)

    def get_colour_mode_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetColorModeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ColorMode
                |     parameter.
                |     Role:Retrieves the state of the ColorMode parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.analysis_setting_att.GetColorModeInfo(io_admin_level, io_locked)

    def get_display_anl_status_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetDisplayAnlStatusInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the DisplayAnlStatus
                |     parameter.
                |     Role:Retrieves the state of the DisplayAnlStatus parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.analysis_setting_att.GetDisplayAnlStatusInfo(io_admin_level, io_locked)

    def get_enable_anl_mode_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetEnableAnlModeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the EnableAnlMode
                |     parameter.
                |     Role:Retrieves the state of the EnableAnlMode parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.analysis_setting_att.GetEnableAnlModeInfo(io_admin_level, io_locked)

    def get_sync_anl_specs_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetSyncAnlSpecsInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the SyncAnlSpecs
                |     parameter.
                |     Role:Retrieves the state of the SyncAnlSpecs parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.analysis_setting_att.GetSyncAnlSpecsInfo(io_admin_level, io_locked)

    def get_visualization_mode_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetVisualizationModeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the VisualizationMode
                |     parameter.
                |     Role:Retrieves the state of the VisualizationMode parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.analysis_setting_att.GetVisualizationModeInfo(io_admin_level, io_locked)

    def get_voxel_static_anl_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetVoxelStaticAnlInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the VoxelStaticAnl
                |     parameter.
                |     Role:Retrieves the state of the VoxelStaticAnl parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.analysis_setting_att.GetVoxelStaticAnlInfo(io_admin_level, io_locked)

    def get_white_mode_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetWhiteModeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the WhiteMode
                |     parameter.
                |     Role:Retrieves the state of the WhiteMode parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.analysis_setting_att.GetWhiteModeInfo(io_admin_level, io_locked)

    def set_analysis_level_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAnalysisLevelLock(boolean iLocked)
                | 
                |     Locks or unlocks the AnalysisLevel parameter.
                |     Role:Locks or unlocks the AnalysisLevel parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.analysis_setting_att.SetAnalysisLevelLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_analysis_level_lock'
        # # vba_code = """
        # # Public Function set_analysis_level_lock(analysis_setting_att)
        # #     Dim iLocked (2)
        # #     analysis_setting_att.SetAnalysisLevelLock iLocked
        # #     set_analysis_level_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_anl_accel_limit_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAnlAccelLimitLock(boolean iLocked)
                | 
                |     Locks or unlocks the AnlAccelLimit parameter.
                |     Role:Locks or unlocks the AnlAccelLimit parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.analysis_setting_att.SetAnlAccelLimitLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_anl_accel_limit_lock'
        # # vba_code = """
        # # Public Function set_anl_accel_limit_lock(analysis_setting_att)
        # #     Dim iLocked (2)
        # #     analysis_setting_att.SetAnlAccelLimitLock iLocked
        # #     set_anl_accel_limit_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_anl_caution_zone_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAnlCautionZoneLock(boolean iLocked)
                | 
                |     Locks or unlocks the AnlCautionZone parameter.
                |     Role:Locks or unlocks the AnlCautionZone parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.analysis_setting_att.SetAnlCautionZoneLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_anl_caution_zone_lock'
        # # vba_code = """
        # # Public Function set_anl_caution_zone_lock(analysis_setting_att)
        # #     Dim iLocked (2)
        # #     analysis_setting_att.SetAnlCautionZoneLock iLocked
        # #     set_anl_caution_zone_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_anl_io_analysis_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAnlIOAnalysisLock(boolean iLocked)
                | 
                |     Locks or unlocks the AnlIOAnalysis parameter.
                |     Role:Locks or unlocks the AnlIOAnalysis parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.analysis_setting_att.SetAnlIOAnalysisLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_anl_io_analysis_lock'
        # # vba_code = """
        # # Public Function set_anl_io_analysis_lock(analysis_setting_att)
        # #     Dim iLocked (2)
        # #     analysis_setting_att.SetAnlIOAnalysisLock iLocked
        # #     set_anl_io_analysis_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_anl_int_dist_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAnlIntDistLock(boolean iLocked)
                | 
                |     Locks or unlocks the AnlIntDist parameter.
                |     Role:Locks or unlocks the AnlIntDist parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.analysis_setting_att.SetAnlIntDistLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_anl_int_dist_lock'
        # # vba_code = """
        # # Public Function set_anl_int_dist_lock(analysis_setting_att)
        # #     Dim iLocked (2)
        # #     analysis_setting_att.SetAnlIntDistLock iLocked
        # #     set_anl_int_dist_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_anl_intf_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAnlIntfLock(boolean iLocked)
                | 
                |     Locks or unlocks the AnlIntf parameter.
                |     Role:Locks or unlocks the AnlIntf parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.analysis_setting_att.SetAnlIntfLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_anl_intf_lock'
        # # vba_code = """
        # # Public Function set_anl_intf_lock(analysis_setting_att)
        # #     Dim iLocked (2)
        # #     analysis_setting_att.SetAnlIntfLock iLocked
        # #     set_anl_intf_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_anl_lin_accel_limit_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAnlLinAccelLimitLock(boolean iLocked)
                | 
                |     Locks or unlocks the AnlLinAccelLimit parameter.
                |     Role:Locks or unlocks the AnlLinAccelLimit parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.analysis_setting_att.SetAnlLinAccelLimitLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_anl_lin_accel_limit_lock'
        # # vba_code = """
        # # Public Function set_anl_lin_accel_limit_lock(analysis_setting_att)
        # #     Dim iLocked (2)
        # #     analysis_setting_att.SetAnlLinAccelLimitLock iLocked
        # #     set_anl_lin_accel_limit_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_anl_lin_speed_limit_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAnlLinSpeedLimitLock(boolean iLocked)
                | 
                |     Locks or unlocks the AnlLinSpeedLimit parameter.
                |     Role:Locks or unlocks the AnlLinSpeedLimit parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.analysis_setting_att.SetAnlLinSpeedLimitLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_anl_lin_speed_limit_lock'
        # # vba_code = """
        # # Public Function set_anl_lin_speed_limit_lock(analysis_setting_att)
        # #     Dim iLocked (2)
        # #     analysis_setting_att.SetAnlLinSpeedLimitLock iLocked
        # #     set_anl_lin_speed_limit_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_anl_measure_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAnlMeasureLock(boolean iLocked)
                | 
                |     Locks or unlocks the AnlMeasure parameter.
                |     Role:Locks or unlocks the AnlMeasure parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.analysis_setting_att.SetAnlMeasureLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_anl_measure_lock'
        # # vba_code = """
        # # Public Function set_anl_measure_lock(analysis_setting_att)
        # #     Dim iLocked (2)
        # #     analysis_setting_att.SetAnlMeasureLock iLocked
        # #     set_anl_measure_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_anl_rot_accel_limit_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAnlRotAccelLimitLock(boolean iLocked)
                | 
                |     Locks or unlocks the AnlRotAccelLimit parameter.
                |     Role:Locks or unlocks the AnlRotAccelLimit parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.analysis_setting_att.SetAnlRotAccelLimitLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_anl_rot_accel_limit_lock'
        # # vba_code = """
        # # Public Function set_anl_rot_accel_limit_lock(analysis_setting_att)
        # #     Dim iLocked (2)
        # #     analysis_setting_att.SetAnlRotAccelLimitLock iLocked
        # #     set_anl_rot_accel_limit_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_anl_rot_speed_limit_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAnlRotSpeedLimitLock(boolean iLocked)
                | 
                |     Locks or unlocks the AnlRotSpeedLimit parameter.
                |     Role:Locks or unlocks the AnlRotSpeedLimit parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.analysis_setting_att.SetAnlRotSpeedLimitLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_anl_rot_speed_limit_lock'
        # # vba_code = """
        # # Public Function set_anl_rot_speed_limit_lock(analysis_setting_att)
        # #     Dim iLocked (2)
        # #     analysis_setting_att.SetAnlRotSpeedLimitLock iLocked
        # #     set_anl_rot_speed_limit_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_anl_travel_limit_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAnlTravelLimitLock(boolean iLocked)
                | 
                |     Locks or unlocks the AnlTravelLimit parameter.
                |     Role:Locks or unlocks the AnlTravelLimit parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.analysis_setting_att.SetAnlTravelLimitLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_anl_travel_limit_lock'
        # # vba_code = """
        # # Public Function set_anl_travel_limit_lock(analysis_setting_att)
        # #     Dim iLocked (2)
        # #     analysis_setting_att.SetAnlTravelLimitLock iLocked
        # #     set_anl_travel_limit_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_anl_velocity_limit_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAnlVelocityLimitLock(boolean iLocked)
                | 
                |     Locks or unlocks the AnlVelocityLimit parameter.
                |     Role:Locks or unlocks the AnlVelocityLimit parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.analysis_setting_att.SetAnlVelocityLimitLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_anl_velocity_limit_lock'
        # # vba_code = """
        # # Public Function set_anl_velocity_limit_lock(analysis_setting_att)
        # #     Dim iLocked (2)
        # #     analysis_setting_att.SetAnlVelocityLimitLock iLocked
        # #     set_anl_velocity_limit_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_ask_anl_mode_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAskAnlModeLock(boolean iLocked)
                | 
                |     Locks or unlocks the AskAnlMode parameter.
                |     Role:Locks or unlocks the AskAnlMode parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.analysis_setting_att.SetAskAnlModeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_ask_anl_mode_lock'
        # # vba_code = """
        # # Public Function set_ask_anl_mode_lock(analysis_setting_att)
        # #     Dim iLocked (2)
        # #     analysis_setting_att.SetAskAnlModeLock iLocked
        # #     set_ask_anl_mode_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_beep_mode_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetBeepModeLock(boolean iLocked)
                | 
                |     Locks or unlocks the BeepMode parameter.
                |     Role:Locks or unlocks the BeepMode parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.analysis_setting_att.SetBeepModeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_beep_mode_lock'
        # # vba_code = """
        # # Public Function set_beep_mode_lock(analysis_setting_att)
        # #     Dim iLocked (2)
        # #     analysis_setting_att.SetBeepModeLock iLocked
        # #     set_beep_mode_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_clash_colour_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetClashColorLock(boolean iLocked)
                | 
                |     Locks or unlocks the ClashColor parameter.
                |     Role:Locks or unlocks the ClashColor parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.analysis_setting_att.SetClashColorLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_clash_color_lock'
        # # vba_code = """
        # # Public Function set_clash_color_lock(analysis_setting_att)
        # #     Dim iLocked (2)
        # #     analysis_setting_att.SetClashColorLock iLocked
        # #     set_clash_color_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_clearance_colour_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetClearanceColorLock(boolean iLocked)
                | 
                |     Locks or unlocks the ClearanceColor parameter.
                |     Role:Locks or unlocks the ClearanceColor parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.analysis_setting_att.SetClearanceColorLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_clearance_color_lock'
        # # vba_code = """
        # # Public Function set_clearance_color_lock(analysis_setting_att)
        # #     Dim iLocked (2)
        # #     analysis_setting_att.SetClearanceColorLock iLocked
        # #     set_clearance_color_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_colour_mode_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetColorModeLock(boolean iLocked)
                | 
                |     Locks or unlocks the ColorMode parameter.
                |     Role:Locks or unlocks the ColorMode parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.analysis_setting_att.SetColorModeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_color_mode_lock'
        # # vba_code = """
        # # Public Function set_color_mode_lock(analysis_setting_att)
        # #     Dim iLocked (2)
        # #     analysis_setting_att.SetColorModeLock iLocked
        # #     set_color_mode_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_display_anl_status_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetDisplayAnlStatusLock(boolean iLocked)
                | 
                |     Locks or unlocks the DisplayAnlStatus parameter.
                |     Role:Locks or unlocks the DisplayAnlStatus parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.analysis_setting_att.SetDisplayAnlStatusLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_display_anl_status_lock'
        # # vba_code = """
        # # Public Function set_display_anl_status_lock(analysis_setting_att)
        # #     Dim iLocked (2)
        # #     analysis_setting_att.SetDisplayAnlStatusLock iLocked
        # #     set_display_anl_status_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_enable_anl_mode_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetEnableAnlModeLock(boolean iLocked)
                | 
                |     Locks or unlocks the EnableAnlMode parameter.
                |     Role:Locks or unlocks the EnableAnlMode parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.analysis_setting_att.SetEnableAnlModeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_enable_anl_mode_lock'
        # # vba_code = """
        # # Public Function set_enable_anl_mode_lock(analysis_setting_att)
        # #     Dim iLocked (2)
        # #     analysis_setting_att.SetEnableAnlModeLock iLocked
        # #     set_enable_anl_mode_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_sync_anl_specs_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetSyncAnlSpecsLock(boolean iLocked)
                | 
                |     Locks or unlocks the SyncAnlSpecs parameter.
                |     Role:Locks or unlocks the SyncAnlSpecs parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.analysis_setting_att.SetSyncAnlSpecsLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_sync_anl_specs_lock'
        # # vba_code = """
        # # Public Function set_sync_anl_specs_lock(analysis_setting_att)
        # #     Dim iLocked (2)
        # #     analysis_setting_att.SetSyncAnlSpecsLock iLocked
        # #     set_sync_anl_specs_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_visualization_mode_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetVisualizationModeLock(boolean iLocked)
                | 
                |     Locks or unlocks the VisualizationMode parameter.
                |     Role:Locks or unlocks the VisualizationMode parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.analysis_setting_att.SetVisualizationModeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_visualization_mode_lock'
        # # vba_code = """
        # # Public Function set_visualization_mode_lock(analysis_setting_att)
        # #     Dim iLocked (2)
        # #     analysis_setting_att.SetVisualizationModeLock iLocked
        # #     set_visualization_mode_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_voxel_static_anl_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetVoxelStaticAnlLock(boolean iLocked)
                | 
                |     Locks or unlocks the VoxelStaticAnl parameter.
                |     Role:Locks or unlocks the VoxelStaticAnl parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.analysis_setting_att.SetVoxelStaticAnlLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_voxel_static_anl_lock'
        # # vba_code = """
        # # Public Function set_voxel_static_anl_lock(analysis_setting_att)
        # #     Dim iLocked (2)
        # #     analysis_setting_att.SetVoxelStaticAnlLock iLocked
        # #     set_voxel_static_anl_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_white_mode_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetWhiteModeLock(boolean iLocked)
                | 
                |     Locks or unlocks the WhiteMode parameter.
                |     Role:Locks or unlocks the WhiteMode parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.analysis_setting_att.SetWhiteModeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_white_mode_lock'
        # # vba_code = """
        # # Public Function set_white_mode_lock(analysis_setting_att)
        # #     Dim iLocked (2)
        # #     analysis_setting_att.SetWhiteModeLock iLocked
        # #     set_white_mode_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'AnalysisSettingAtt(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_str_functional_interfaces.sfm_split_plate import SFMSplitPlate
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class SFMSplitPlates(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     SfmSplitPlates
                | 
                | Interface to manage the Structure Functional Modeler Split Plates
                | object.
                | Role: Provides access to split plates of a super plate as a
                | collection.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=SFMSplitPlate)
        self.sfm_split_plates = com_object

    def item(self, i_index: cat_variant) -> SFMSplitPlate:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As SfmSplitPlate
                | 
                |     Gets Split Plate.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             [in] Index of the Split Plate to be retrieved. 
                |         oSfmSplitPlate
                |             [out] The retrieved Split Plate. 
                | 
                |     Returns:
                |         S_OK if everything ran ok
                | 
                |         Example:
                |             This example gets existing Split Plate of a Super
                |             Plate.
                | 
                |              Dim ListSplitPlates As SfmSplitPlates
                |              Set ListSplitPlates = SuperPlate.SplitPlatesObjects
                |              Dim Split_Plate As SfmSplitPlate
                |              Set Split_Plate = ListSplitPlates.Item(i)
                |              Next

        :param cat_variant i_index:
        :rtype: SFMSplitPlate
        """
        return SFMSplitPlate(self.sfm_split_plates.Item(i_index))

    def __repr__(self):
        return f'SFMSplitPlates(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.page_setup import PageSetup
from pycatia.in_interfaces.viewer import Viewer
from pycatia.in_interfaces.viewers import Viewers
from pycatia.system_interfaces.any_object import AnyObject


class Window(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     Window
                | 
                | Represents the window.
                | The window is the object that accommodates one or several viewers to display
                | your objects, and which makes the link with the windowing
                | system.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.window = com_object

    @property
    def active_viewer(self) -> Viewer:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ActiveViewer() As Viewer (Read Only)
                | 
                |     Returns the active viewer in the window.
                | 
                |     Example:
                |         This example retrieves the active viewer in the CADWindow window in
                |         ViewerToWorkIn.
                | 
                |          Dim ViewerToWorkIn As Viewer
                |          Set ViewerToWorkIn = CADWindow.ActiveViewer

        :rtype: Viewer
        """

        return Viewer(self.window.ActiveViewer)

    @property
    def caption(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Caption() As CATBSTR
                | 
                |     Returns or sets the window caption. The window caption is displayed in the
                |     title bar.
                | 
                |     Example:
                |         This example sets the window caption for the CADWindow window to: CAD
                |         3D Window.
                | 
                |          CADWindow.Caption = "CAD 3D Window"

        :rtype: str
        """

        return self.window.Caption

    @caption.setter
    def caption(self, value: str):
        """
        :param str value:
        """

        self.window.Caption = value

    @property
    def height(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Height() As long
                | 
                |     Returns or sets the window height. The window height is expressed in
                |     pixels.
                | 
                |     Example:
                |         This example sets the window height for the CADWindow window to 300
                |         pixels.
                | 
                |          CADWindow.Width = 300

        :rtype: int
        """

        return self.window.Height

    @height.setter
    def height(self, value: int):
        """
        :param int value:
        """

        self.window.Height = value

    @property
    def left(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Left() As long
                | 
                |     Returns or sets the distance of the window with respect to the inner left
                |     side of the frame. This distance is expressed in pixels.
                | 
                |     Example:
                |         This example sets the distance of the window with respect to the inner
                |         left side of the frame for the CADWindow window to 150
                |         pixels.
                | 
                |          CADWindow.Left = 150

        :rtype: int
        """

        return self.window.Left

    @left.setter
    def left(self, value: int):
        """
        :param int value:
        """

        self.window.Left = value

    @property
    def page_setup(self) -> PageSetup:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property PageSetup() As PageSetup
                | 
                |     Returns or sets the page setup of the window. The page setup includes all
                |     parameters to print the window.
                | 
                |     Example:
                |         This example sets the page setup for the CADWindow window to an
                |         existing page setup for the A4 paper size A4PageSetup.
                | 
                |          CADWindow.PageSetup = A4PageSetup

        :rtype: PageSetup
        """

        return PageSetup(self.window.PageSetup)

    @page_setup.setter
    def page_setup(self, value: PageSetup):
        """
        :param PageSetup value:
        """

        self.window.PageSetup = value

    @property
    def top(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Top() As long
                | 
                |     Returns or sets the distance of the window with respect to the inner top
                |     side of the frame. This distance is expressed in pixels.
                | 
                |     Example:
                |         This example sets the distance of the window with respect to the inner
                |         top side of the frame for the CADWindow window to 50
                |         pixels.
                | 
                |          CADWindow.Top = 50

        :rtype: int
        """

        return self.window.Top

    @top.setter
    def top(self, value: int):
        """
        :param int value:
        """

        self.window.Top = value

    @property
    def viewers(self) -> Viewers:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Viewers() As Viewers (Read Only)
                | 
                |     Returns the collection of viewers attached to the window.
                | 
                |     Example:
                |         This example retrieves the collection of viewers attached to the
                |         CADWindow window in ViewerCollection.
                | 
                |          Dim ViewerCollection As Viewers
                |          Set ViewerCollection = CADWindow.Viewers

        :rtype: Viewers
        """

        return Viewers(self.window.Viewers)

    @property
    def width(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Width() As long
                | 
                |     Returns or sets the window width. The window width is expressed in
                |     pixels.
                | 
                |     Example:
                |         This example sets the window width for the CADWindow window to 450
                |         pixels.
                | 
                |          CADWindow.Width = 450

        :rtype: int
        """

        return self.window.Width

    @width.setter
    def width(self, value: int):
        """
        :param int value:
        """

        self.window.Width = value

    @property
    def window_state(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property WindowState() As CatWindowState
                | 
                |     Returns or sets the window state.
                | 
                |     Example:
                |         This example sets the window state for the CADWindow window to
                |         catWindowStateMaximized.
                | 
                |          CADWindow.WindowState = catWindowStateMaximized

        :return: enum cat_window_state
        :rtype: int
        """

        return self.window.WindowState

    @window_state.setter
    def window_state(self, value: int):
        """
        :param int value: enum cat_window_state
        """

        self.window.WindowState = value

    def activate(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub Activate()
                | 
                |     Activates a window. The active window is deactivated and the window to
                |     which the method applies is activated instead.
                | 
                |     Example:
                |         This example activates the CADWindow window.
                | 
                |          CADWindow.Activate()

        :rtype: None
        """
        return self.window.Activate()

    def activate_next(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub ActivateNext()
                | 
                |     Activates the window following the current active one in the window
                |     collection.
                | 
                |     Example:
                |         This example activates the window following the current CADWindow
                |         window in the window collection.
                | 
                |          CADWindow.ActivateNext()

        :rtype: None
        """
        return self.window.ActivateNext()

    def activate_previous(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub ActivatePrevious()
                | 
                |     Activates the window preceding the current active one in the window
                |     collection.
                | 
                |     Example:
                |         This example activates the window preceding the current CADWindow
                |         window in the window collection.
                | 
                |          CADWindow.ActivatePrevious()

        :rtype: None
        """
        return self.window.ActivatePrevious()

    def close(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub Close()
                | 
                |     Closes the window. This method displays the dialog box requesting whether
                |     to save the file if the document was modified, except if the
                |     Application.DisplayFileAlerts property was previously set to
                |     False.
                | 
                |     Example:
                |         This example closes the CADWindow window.
                | 
                |          CADWindow.Close()

        :rtype: None
        """
        return self.window.Close()

    def new_window(self) -> 'Window':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func NewWindow() As Window
                | 
                |     Creates a new window. The new window displays the same document with the
                |     same viewers and viewpoints than the window to which the method applies, and
                |     becomes the active one.
                | 
                |     Example:
                |         This example creates a new window named CADNewWindow from the CADWindow
                |         window.
                | 
                |          Dim CADNewWindow As Window
                |          Set CADNewWindow = CADWindow.NewWindow()

        :rtype: Window
        """
        return Window(self.window.NewWindow())

    def print_out(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub PrintOut()
                | 
                |     Prints the active viewer of the window according to the window's page setup
                |     on the default printer.
                | 
                |     Example:
                |         This example prints the CADWindow window's active viewer on the default
                |         printer.
                | 
                |          CADWindow.PrintOut()

        :rtype: None
        """
        return self.window.PrintOut()

    def print_to_file(self, file_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub PrintToFile(CATBSTR fileName)
                | 
                |     Prints the active viewer of the window according to the window's page setup
                |     in a file instead of being sent to a printer.
                | 
                |     Parameters:
                | 
                |         fileName
                |             The full pathname of the file receiving the data. 
                | 
                |     Example:
                |         This example prints the CADWindow window's active viewer in a
                |         file.
                | 
                |          CADWindow.PrintToFile("e:\\temp\\cadwin.prn")

        :param str file_name:
        :rtype: None
        """
        return self.window.PrintToFile(file_name)

    def __repr__(self):
        return f'Window(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dmaps_interfaces.activity import Activity
from pycatia.system_interfaces.any_object import AnyObject


class MountActivity(Activity):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DMAPSInterfaces.Activity
                |                         MountActivity
                | 
                | Interface representing a Mount Activity.
                | 
                | Role: This interface is used to retieve/assign the value of motion
                | targets/attrs for the move activity.
                | The following code snippet can be used to obtain a MoveJointActivity from a
                | selected Activity
                | 
                |    Dim oSelectAct As Activity
                |    set oSelectAct = CATIA.ActiveDocument.Selection.FindObject("CATIAActivity")
                |    Dim objMountAct As MountActivity
                |    set objMountAct = oSelectAct.GetTechnologicalObject("MountActivity")
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.mount_activity = com_object

    @property
    def tool(self) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Tool() As AnyObject
                | 
                |     This property returns and sets the tool to mount.
                | 
                |     Returns:
                |         oTool The tool to mount. 
                |     Parameters:
                | 
                |         iTool
                |             The tool to mount. 
                | 
                |     Example:
                |
                |            Dim objMountAct As MountActivity
                |                   ......
                |            Dim  objTool As Product
                |            set objTool=objMountAct.Tool
                |            ..
                |            objMountAct.Tool=objTool

        :rtype: AnyObject
        """

        return AnyObject(self.mount_activity.Tool)

    @tool.setter
    def tool(self, value: AnyObject):
        """
        :param AnyObject value:
        """

        self.mount_activity.Tool = value

    @property
    def tool_profile(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ToolProfile() As CATBSTR
                | 
                |     Sets and Retreives Tool Profile to use after mounting
                | 
                |     Returns:
                |         oToolProfile Name of the tool profile available in the Generic Robot
                |         Controller set. 
                |     Parameters:
                | 
                |         iToolProfile
                |             Name of the tool profile available in the Generic Robot Controller
                |             to set. 
                | 
                |     Example:
                |
                |            Dim objMountAct As MountActivity
                |                   ......
                |            Dim  ToolPrName As String
                |            set ToolPrName=objMountAct.ToolProfile
                |            ToolPrName  = "Tool.1"
                |            objMountAct.ToolProfile=ToolPrName

        :rtype: str
        """

        return self.mount_activity.ToolProfile

    @tool_profile.setter
    def tool_profile(self, value: str):
        """
        :param str value:
        """

        self.mount_activity.ToolProfile = value

    def __repr__(self):
        return f'MountActivity(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_plant_ship_interfaces.psp_list_of_bstrs import PSPListOfBSTRs
from pycatia.product_structure_interfaces.product import Product
from pycatia.system_interfaces.any_object import AnyObject


class PSPBuildPart(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     PspBuildPart
                | 
                | Represents Interface to create and modify a part.
                | Role: To build and define a part.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.psp_build_part = com_object

    def change_part_type(self, i_ref_part: Product, iu_part_type: str, u_part_number: str) -> Product:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ChangePartType(Product iRefPart,
                | CATBSTR iuPartType,
                | CATBSTR uPartNumber) As Product
                | 
                |     Returns the part after changing the part type of an existing
                |     part.
                | 
                |     Parameters:
                | 
                |         iReferencePart
                |             Reference Product in CATPart document to modify. 
                |         iPartType
                |             New part class type. 
                |         iPartNumber
                |             New Part number. 
                | 
                |     Returns:
                |         New reference Product in CATPart document
                |
                |     Example:
                |
                |          Dim objThisIntf As PspBuildPart
                |          Dim iRefPart As   Product
                |          Dim iuPartType As CATBSTR
                |          Dim uPartNumber As CATBSTR
                |          Dim oNewRefPart As Product
                |           ...
                |          Set oNewRefPart= objThisIntf.ChagePartType (iRefPart, iuPartType,
                |          uPartNumber )

        :param Product i_ref_part:
        :param str iu_part_type:
        :param str u_part_number:
        :rtype: Product
        """
        return Product(self.psp_build_part.ChangePartType(i_ref_part.com_object, iu_part_type, u_part_number))

    def list_part_parametric_attributes(self, i_ref_part: Product) -> PSPListOfBSTRs:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ListPartParametricAttributes(Product iRefPart) As
                | PspListOfBSTRs
                | 
                |     Returns the part parametric attribute names.
                | 
                |     Parameters:
                | 
                |         iRefPart
                |             Reference Product in new CATPart document. 
                | 
                |     Returns:
                |         List of parametric attribute names.
                |
                |     Example:
                |
                |          Dim objThisIntf As PspBuildPart
                |          Dim iRefPart As Product
                |          Dim oLAttributeNames As PspListOfBSTRs
                |           ...
                |          Set oLAttributeNames = objThisIntf.ListPartParametricAttributes (iRefPart)

        :param Product i_ref_part:
        :rtype: PSPListOfBSTRs
        """
        return PSPListOfBSTRs(self.psp_build_part.ListPartParametricAttributes(i_ref_part.com_object))

    def new_part(self, iu_part_type: str, u_part_number: str) -> Product:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func NewPart(CATBSTR iuPartType,
                | CATBSTR uPartNumber) As Product
                | 
                |     Create a new part.
                | 
                |     Parameters:
                | 
                |         iPartType
                |             Part class type. 
                |         iPartNumber
                |             Part number. 
                | 
                |     Returns:
                |         Retruns Reference Product pointer in new CATPart document.
                |         
                |     Example:
                |
                |          Dim objThisIntf As PspBuildPart
                |          Dim iuPartType As CATBSTR
                |          Dim uPartNumber As CATBSTR
                |          Dim oNewRefPart As Product
                |           ...
                |          Set oNewRefPart = objThisIntf.NewPart (iuPartType, uPartNumber)

        :param str iu_part_type:
        :param str u_part_number:
        :rtype: Product
        """
        return Product(self.psp_build_part.NewPart(iu_part_type, u_part_number))

    def set_part_parametric_attributes(self, i_ref_part: Product, i_l_attribute_names: PSPListOfBSTRs) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetPartParametricAttributes(Product iRefPart,
                | PspListOfBSTRs iLAttributeNames)
                | 
                |     Sets the part parametric attribute names.
                | 
                |     Parameters:
                | 
                |         iRefPart
                |             Reference Product in new CATPart document. 
                |         iLAttributeNames
                |             List of parametric attribute names. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspBuildPart
                |          Dim iRefPart As Product
                |          Dim iLAttributeNames As PspListOfBSTRs
                |           ...
                |          objThisIntf.SetPartParametricAttributes iRefPart,
                |          iLAttributeNames

        :param Product i_ref_part:
        :param PSPListOfBSTRs i_l_attribute_names:
        :rtype: None
        """
        return self.psp_build_part.SetPartParametricAttributes(i_ref_part.com_object, i_l_attribute_names.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_part_parametric_attributes'
        # # vba_code = """
        # # Public Function set_part_parametric_attributes(psp_build_part)
        # #     Dim iRefPart (2)
        # #     psp_build_part.SetPartParametricAttributes iRefPart
        # #     set_part_parametric_attributes = iRefPart
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'PSPBuildPart(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import Iterator

from pycatia.knowledge_interfaces.parameter_set import ParameterSet
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class ParameterSets(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     ParameterSets
                | 
                | Represents a collection of parameter sets.
                | The ParameterSet object is a neutral object that contains parameters, like the
                | Parameters node in the specification tree.
                | 
                | The following example shows how to retrieve it on a part:
                | 
                |  Dim CATDocs As Documents
                |  Set CATDocs = CATIA.Documents
                |  Dim part1 As Document
                |  Set part1   = CATDocs.Add("CATPart")
                |  Dim parameters1 As Parameters
                |  Set parameters1 = part1.Part.Parameters
                |  Dim ParameterSet1 As ParameterSet
                |  Set ParameterSet1 = parameters1.RootParameterSet
                |  Dim parameterSets1 As ParameterSets
                |  Set parameterSets1 = parameterSet1.ParameterSets
                |  
                | 
                | This collection is not a collection of all parameter sets of a document, but a
                | collection of all parameter sets in the current parameter set.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=ParameterSet)
        self.parameter_sets = com_object

    def create_set(self, i_name: str) -> ParameterSet:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func CreateSet(CATBSTR iName) As ParameterSet
                | 
                |     Creates a set of parameters and appends it to the parameter set which
                |     corresponds to this collection.

        :param str i_name:
        :rtype: ParameterSet
        """
        return ParameterSet(self.parameter_sets.CreateSet(i_name))

    def item(self, i_index: cat_variant) -> ParameterSet:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func Item(CATVariant iIndex) As ParameterSet
                | 
                |     Returns a parameter set using its index or its name from the ParameterSets
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the parameter set to retrieve from the
                |             collection of parameter sets. As a numerics, this index is the rank of the
                |             parameter set in the collection. The index of the first parameter set in the
                |             collection is 1, and the index of the last parameter set is Count. As a string,
                |             it is the name you assigned to the parameter set using the
                |             
                | 
                |         AnyObject.Name property . 
                |     Example:
                |         This example retrieves the parameter set named "Parameters.1" in the
                |         parameterSets collection:
                | 
                |          Set theSet = parameterSets.Item("Parameters.1")

        :param cat_variant i_index:
        :rtype: ParameterSet
        """
        return ParameterSet(self.parameter_sets.Item(i_index))

    def __getitem__(self, n: int) -> ParameterSet:
        if (n + 1) > self.count:
            raise StopIteration

        return ParameterSet(self.parameter_sets.Item(n + 1))

    def __iter__(self) -> Iterator[ParameterSet]:
        for i in range(self.count):
            yield self.child_object(self.com_object.Item(i + 1))

    def __repr__(self):
        return f'ParameterSets(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.document import Document
from pycatia.navigator_interfaces.group import Group
from pycatia.product_structure_interfaces.product import Product
from pycatia.system_interfaces.any_object import AnyObject
from pycatia.system_interfaces.collection import Collection


class VibrationVolumes(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     VibrationVolumes
                | 
                | Interface to compute vibration volumes
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.vibration_volumes = com_object

    def clean_up(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub CleanUp()
                | 
                |     Cleans up.

        :rtype: None
        """
        return self.vibration_volumes.CleanUp()

    def compute_vibration_volume(
            self,
            group_of_selected_products: Group,
            positions_file_path: str,
            i_accuracy: float,
            i_simplif_accuracy: float
    ) -> Document:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ComputeVibrationVolume(Group GroupOfSelectedProducts,
                | CATBSTR PositionsFilePath,
                | double iAccuracy,
                | double iSimplifAccuracy) As Document
                | 
                |     Computes a vibration volume, from a position input file.
                | 
                |     Parameters:
                | 
                |         GroupOfSelectedProducts
                |             Selection of products to make vibrate. 
                |         PositionsFilePath
                |             Positions file path. 
                |         iAccuracy
                |             Grain for wrapping. 
                |         iSimplifAccuracy
                |             Accuracy for simplification. A non positive value makes the
                |             simplification inactive. 
                | 
                |     Returns:
                |         VibrationVolumeDocument: Document containing the result.

        :param Group group_of_selected_products:
        :param str positions_file_path:
        :param float i_accuracy:
        :param float i_simplif_accuracy:
        :rtype: Document
        """
        return Document(
            self.vibration_volumes.ComputeVibrationVolume(
                group_of_selected_products.com_object,
                positions_file_path,
                i_accuracy,
                i_simplif_accuracy
            )
        )

    def compute_vibration_volume_from_track(
            self,
            group_of_selected_products: Group,
            i_swept_able: AnyObject,
            i_accuracy: float,
            i_simplify_accuracy: float
    ) -> Document:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ComputeVibrationVolumeFromTrack(Group
                | GroupOfSelectedProducts,
                | CATBaseDispatch iSweptAble,
                | double iAccuracy,
                | double iSimplifAccuracy) As Document
                | 
                |     Computes a vibration volume, from a track.
                | 
                |     Parameters:
                | 
                |         GroupOfSelectedProducts
                |             Selection of products to make vibrate. 
                |         iSweptAble
                |             Track containing the positions. 
                |         iAccuracy
                |             Grain for wrapping. 
                |         iSimplifAccuracy
                |             Accuracy for simplification. A non positive value makes the
                |             simplification inactive. 
                | 
                |     Returns:
                |         VibrationVolumeDocument: Document containing the result.

        :param Group group_of_selected_products:
        :param AnyObject i_swept_able:
        :param float i_accuracy:
        :param float i_simplify_accuracy:
        :rtype: Document
        """
        return Document(
            self.vibration_volumes.ComputeVibrationVolumeFromTrack(
                group_of_selected_products.com_object,
                i_swept_able.com_object,
                i_accuracy,
                i_simplify_accuracy
            )
        )

    def compute_vibration_volume_from_track_with_a_reference(
            self,
            group_of_selected_products: Group,
            i_reference_product: Product,
            i_swept_able: AnyObject,
            i_accuracy: float,
            i_simplify_accuracy: float
    ) -> Document:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ComputeVibrationVolumeFromTrackWithAReference(Group
                | GroupOfSelectedProducts,
                | Product iReferenceProduct,
                | CATBaseDispatch iSweptAble,
                | double iAccuracy,
                | double iSimplifAccuracy) As Document
                | 
                |     Computes a vibration volume, from a track, according to a reference
                |     product.
                | 
                |     Parameters:
                | 
                |         GroupOfSelectedProducts
                |             Selection of products to make vibrate. 
                |         iReferenceProduct
                |             Product taken as a reference. 
                |         iSweptAble
                |             Track containing the positions. 
                |         iAccuracy
                |             Grain for wrapping. 
                |         iSimplifAccuracy
                |             Accuracy for simplification. A non positive value makes the
                |             simplification inactive. 
                | 
                |     Returns:
                |         VibrationVolumeDocument: Document containing the result.

        :param Group group_of_selected_products:
        :param Product i_reference_product:
        :param AnyObject i_swept_able:
        :param float i_accuracy:
        :param float i_simplify_accuracy:
        :rtype: Document
        """
        return Document(
            self.vibration_volumes.ComputeVibrationVolumeFromTrackWithAReference(
                group_of_selected_products.com_object,
                i_reference_product.com_object,
                i_swept_able.com_object,
                i_accuracy,
                i_simplify_accuracy
            )
        )

    def compute_vibration_volume_with_a_reference(
            self,
            i_group_of_selected_products: Group,
            i_reference_product: Product,
            positions_file_path: str,
            i_accuracy: float,
            i_simplify_accuracy: float
    ) -> Document:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ComputeVibrationVolumeWithAReference(Group
                | iGroupOfSelectedProducts,
                | Product iReferenceProduct,
                | CATBSTR PositionsFilePath,
                | double iAccuracy,
                | double iSimplifAccuracy) As Document
                | 
                |     Computes a vibration volume, from a position input file, according to a
                |     reference product.
                | 
                |     Parameters:
                | 
                |         iGroupOfSelectedProducts
                |             Selection of products to make vibrate. 
                |         iReferenceProduct
                |             Product taken as a reference. 
                |         PositionsFilePath
                |             Positions file path. 
                |         iAccuracy
                |             Grain for wrapping. 
                |         iSimplifAccuracy
                |             Accuracy for simplification. A non positive value makes the
                |             simplification inactive. 
                | 
                |     Returns:
                |         VibrationVolumeDocument: Document containing the result.

        :param Group i_group_of_selected_products:
        :param Product i_reference_product:
        :param str positions_file_path:
        :param float i_accuracy:
        :param float i_simplify_accuracy:
        :rtype: Document
        """
        return Document(
            self.vibration_volumes.ComputeVibrationVolumeWithAReference(
                i_group_of_selected_products.com_object,
                i_reference_product.com_object,
                positions_file_path,
                i_accuracy,
                i_simplify_accuracy
            )
        )

    def vibration_volume_shape_name(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func VibrationVolumeShapeName() As CATBSTR
                | 
                |     Returns the name of the associated shape.

        :rtype: str
        """
        return self.vibration_volumes.VibrationVolumeShapeName()

    def __repr__(self):
        return f'VibrationVolumes(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dmaps_interfaces.activity import Activity


class TCPTraceActivity(Activity):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DMAPSInterfaces.Activity
                |                         TCPTraceActivity
                | 
                | Interface representing TCPTraceActivity.
                | 
                | Role: This interface is used to work with TCPTraceActivity which consists of a
                | various attributes.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.tcp_trace_activity = com_object

    def get_line_colour(self, o_r: int, o_g: int, o_b: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetLineColor(long oR,
                | long oG,
                | long oB)
                | 
                |     Indicates the line Color property of trace.
                | 
                |     Parameters:
                | 
                |         oR,oG,oB
                |             long. Get the line Color property defined in the trace
                |             activity(R,G,B values).

        :param int o_r:
        :param int o_g:
        :param int o_b:
        :rtype: None
        """
        return self.tcp_trace_activity.GetLineColor(o_r, o_g, o_b)

    def get_line_thickness(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetLineThickness() As long
                | 
                |     Indicates the line thickness property of trace.
                | 
                |     Parameters:
                | 
                |         oThickness
                |             long. Get the line thickness property defined in the trace
                |             activity.

        :rtype: int
        """
        return self.tcp_trace_activity.GetLineThickness()

    def get_line_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetLineType() As long
                | 
                |     Indicates the line type property of trace.
                | 
                |     Parameters:
                | 
                |         oType
                |             long. Get the line type property defined in the trace
                |             activity.

        :rtype: int
        """
        return self.tcp_trace_activity.GetLineType()

    def get_tcp_trace_mode(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetTCPTraceMode() As boolean
                | 
                |     Indicates if the tracing capability is active or not.
                | 
                |         True: tracing capability activated
                |         False: tracing capability deactivated
                | 
                |     Parameters:
                | 
                |         oTCPTraceMode
                |             Boolean. Indicates if the tracing capability is active or
                |             not.

        :rtype: bool
        """
        return self.tcp_trace_activity.GetTCPTraceMode()

    def set_line_colour(self, i_r: int, i_g: int, i_b: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetLineColor(long iR,
                | long iG,
                | long iB)
                | 
                |     Indicates the line Color property of trace.
                | 
                |     Parameters:
                | 
                |         iR,iG,iB
                |             long. Set the line Color property for the trace activity(R,G,B
                |             values).

        :param int i_r:
        :param int i_g:
        :param int i_b:
        :rtype: None
        """
        return self.tcp_trace_activity.SetLineColor(i_r, i_g, i_b)

    def set_line_thickness(self, i_thickness: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetLineThickness(long iThickness)
                | 
                |     Indicates the line thickness property of trace.
                | 
                |     Parameters:
                | 
                |         iThickness
                |             long. Set the line thickness property for the trace
                |             activity.

        :param int i_thickness:
        :rtype: None
        """
        return self.tcp_trace_activity.SetLineThickness(i_thickness)

    def set_line_type(self, i_type: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetLineType(long iType)
                | 
                |     Indicates the line type property of trace.
                | 
                |     Parameters:
                | 
                |         iType
                |             long. Set the line type property for the trace.

        :param int i_type:
        :rtype: None
        """
        return self.tcp_trace_activity.SetLineType(i_type)

    def set_tcp_trace_mode(self, i_tcp_trace_mode: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetTCPTraceMode(boolean iTCPTraceMode)
                | 
                |     Set the tracing capability as active or not.
                | 
                |         True: tracing capability activated
                |         False: tracing capability deactivated
                | 
                |     Parameters:
                | 
                |         iTCPTraceMode
                |             Boolean. Value to set.

        :param bool i_tcp_trace_mode:
        :rtype: None
        """
        return self.tcp_trace_activity.SetTCPTraceMode(i_tcp_trace_mode)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_tcp_trace_mode'
        # # vba_code = """
        # # Public Function set_tcp_trace_mode(tcp_trace_activity)
        # #     Dim iTCPTraceMode (2)
        # #     tcp_trace_activity.SetTCPTraceMode iTCPTraceMode
        # #     set_tcp_trace_mode = iTCPTraceMode
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'TCPTraceActivity(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.analysis_interfaces.analysis_manager import AnalysisManager
from pycatia.in_interfaces.document import Document


class AnalysisDocument(Document):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     InfInterfaces.Document
                |                         AnalysisDocument
                | 
                | Represents the document object for analysis.
                | This objects is used for all CAE applications to defines specifications and
                | managed associated results.
                | The document for analysis data is typed as ".CATAnalysis".
                | When an analysis document object is created, an analysis manager is also
                | created.
                | This analysis manager is the root object at the top of the structure of the
                | Analysis document.
                | 
                | See also:
                |     Document
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.analysis_document = com_object

    @property
    def analysis(self) -> AnalysisManager:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Analysis() As AnalysisManager (Read Only)
                | 
                |     Returns the root analysis object from the current analysis
                |     document.
                | 
                |     Example:
                |         The following example returns in RootAnalysis the root analysis object
                |         of the active document, assumed to be an analysis
                |         document:
                | 
                |          Dim AnalysisDocument As Document
                |          Set AnalysisDocument = CATIA.ActiveDocument
                |          Dim RootAnalysis As AnalysisManager
                |          Set RootAnalysis = AnalysisDocument.Analysis

        :rtype: AnalysisManager
        """

        return AnalysisManager(self.analysis_document.Analysis)

    def __repr__(self):
        return f'AnalysisDocument(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dmaps_interfaces.activity import Activity
from pycatia.dnb_igp_setup_interfaces.operation import Operation
from pycatia.system_interfaces.any_object import AnyObject


class RobotTask(Activity):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DMAPSInterfaces.Activity
                |                         RobotTask
                | 
                | Represents the Robot Task.
                | 
                | Role: The interface is used manage activities under a Robot
                | Task.
                | The following code snippet can be used to obtain the Robot Task from a Robot
                | Task Factory.
                | 
                |    Dim objRobotTaskFactory As RobotTaskFactory
                |    Dim objRobot As Product
                |    ...
                |    Set objRobotTaskFactory = objRobot.GetTechnologicalObject("RobotTaskFactory" )
                |    Dim objRobotTaskList(3) as RobotTask
                |    Dim objRobotTask as RobotTask
                |    objRobotTaskFactory.GetAllRobotTasks objRobotTaskList
                |    objRobotTask=objRobotTaskList[0]
                |
                | The Robot Task can also be obtained from an activity of the type
                | RobotTask.
                | 
                |    Dim objActivity as Activity
                |    ...
                |    Dim objRobotTask as RobotTask
                |    Set objRobotTask = objActivity.GetTechnologicalObject("RobotTask" )
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.robot_task = com_object

    def create_after_operation(self, i_after_operation: Operation, o_created_operation: Operation) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub CreateAfterOperation(Operation iAfterOperation,
                | Operation oCreatedOperation)
                | 
                |     Creates Operation as a child of Robot Task.
                | 
                |     Parameters:
                | 
                |         iAfterOperation
                |             The Operation after which the required operation is to be created.
                |             
                |         oCreatedOperation
                |             The Created Operation. 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The operation was successfully created.
                |         E_FAIL
                |             The operation could not be created.
                | 
                |         Example:
                |             The following example creates an Operation
                | 
                |                Dim objRobotTask as RobotTask
                |                Dim objAfterOperation As Operation
                |                ...
                |                Dim objOperation As Operation
                |                objRobotTask.CreateAfterOperation
                |                objAfterOperation,objOperation

        :param Operation i_after_operation:
        :param Operation o_created_operation:
        :rtype: None
        """
        return self.robot_task.CreateAfterOperation(i_after_operation.com_object, o_created_operation.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'create_after_operation'
        # # vba_code = """
        # # Public Function create_after_operation(robot_task)
        # #     Dim iAfterOperation (2)
        # #     robot_task.CreateAfterOperation iAfterOperation
        # #     create_after_operation = iAfterOperation
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def create_call_task(
            self,
            i_robot_task: 'RobotTask',
            i_after_operation: Operation,
            i_where: bool,
            o_created_call_task: AnyObject
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub CreateCallTask(RobotTask iRobotTask,
                | Operation iAfterOperation,
                | boolean iWhere,
                | AnyObject oCreatedCallTask)
                | 
                |     Creates a calltask inside a Robot Task
                | 
                |     Parameters:
                | 
                |         iRobotTask
                |             The task to be called in the current robot task 
                |         iAfterOperation
                |             The Operation after which the required operation is to be created..
                |             
                |         iWhere
                |             The postion of where the task needs to be inserted Before(0)
                |             After(1) 
                |         oCreatedCallTask
                |             The created call task 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The call task was successfully created.
                |         E_FAIL
                |             The call task could not be created.
                | 
                |         Example:
                |             The following example creates An Operation
                | 
                |                Dim objRobotTask as RobotTask
                |                Dim objCalledTask as RobotTask
                |                Dim objAfterOperation as Operation
                |                ..
                |                Dim objCallTaskAct as AnyObject
                |                objRobotTask.CreateCallTask objCalledTask,objAfterOperation,1,objCallTaskAct

        :param RobotTask i_robot_task:
        :param Operation i_after_operation:
        :param bool i_where:
        :param AnyObject o_created_call_task:
        :rtype: None
        """
        return self.robot_task.CreateCallTask(
            i_robot_task.com_object,
            i_after_operation.com_object,
            i_where,
            o_created_call_task.com_object
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'create_call_task'
        # # vba_code = """
        # # Public Function create_call_task(robot_task)
        # #     Dim iRobotTask (2)
        # #     robot_task.CreateCallTask iRobotTask
        # #     create_call_task = iRobotTask
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def create_operation(
            self,
            i_reference_operation: Operation,
            i_after_operation: Operation,
            o_created_operation: Operation
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub CreateOperation(Operation iReferenceOperation,
                | Operation iAfterOperation,
                | Operation oCreatedOperation)
                | 
                |     Creates Operation as a child of Robot Task.
                | 
                |     Parameters:
                | 
                |         iReferenceOperation
                |             The Reference Operation after which the Operation has to be created
                |             and whose properties will be copied to the created operation.
                |             
                |         iAfterOperation
                |             The Operation after which the required operation is to be created.
                |             (Pass NOTHING if Reference Operation is specified)
                |             
                |         oCreatedOperation
                |             The Created Operation. 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The operation was successfully created.
                |         E_FAIL
                |             The operation could not be created.
                | 
                |         Example:
                |             The following example creates an Operation
                | 
                |                Dim objRobotTask as RobotTask
                |                Dim objRefOperation as Operation
                |                ...
                |                Dim objAfterOperation as Operation
                |                Set objAfterOperation = Nothing
                |                Dim objOperation As Operation
                |                objRobotTask.CreateOperation
                |                objRefOperation,objAfterOperation,objOperation

        :param Operation i_reference_operation:
        :param Operation i_after_operation:
        :param Operation o_created_operation:
        :rtype: None
        """
        return self.robot_task.CreateOperation(
            i_reference_operation.com_object,
            i_after_operation.com_object,
            o_created_operation.com_object
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'create_operation'
        # # vba_code = """
        # # Public Function create_operation(robot_task)
        # #     Dim iReferenceOperation (2)
        # #     robot_task.CreateOperation iReferenceOperation
        # #     create_operation = iReferenceOperation
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def delete_operations(self, i_operation_list: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub DeleteOperations(CATSafeArrayVariant iOperationList)
                | 
                |     Deletes the required list of Operations.
                | 
                |     Parameters:
                | 
                |         iOperationList
                |             The list of Operations to be deleted. 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The operation list was successfully deleted.
                |         E_FAIL
                |             The operation list could not be created.
                | 
                |         Example:
                |             The following example creates an Operation
                | 
                |                Dim objRobotTask as RobotTask
                |                Dim objOperationList as Operation
                |                ...
                |                objRobotTask.DeleteOperations objOperationList

        :param tuple i_operation_list:
        :rtype: None
        """
        return self.robot_task.DeleteOperations(i_operation_list)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'delete_operations'
        # # vba_code = """
        # # Public Function delete_operations(robot_task)
        # #     Dim iOperationList (2)
        # #     robot_task.DeleteOperations iOperationList
        # #     delete_operations = iOperationList
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_all_operations(self, o_operation_list: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetAllOperations(CATSafeArrayVariant oOperationList)
                | 
                |     Retrieves the List of Operations of Robot Task.
                | 
                |     Parameters:
                | 
                |         oOperationList
                |             The list of Operations 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The operation list was successfully queried.
                |         E_FAIL
                |             The operation list could not be queried.
                | 
                |         Example:
                |             The following example creates An Operation
                | 
                |                Dim objRobotTask as RobotTask
                |                Dim objOperationList As Operation
                |                ...
                |                objRobotTask.GetAllOperations objOperationList

        :param tuple o_operation_list:
        :rtype: None
        """
        return self.robot_task.GetAllOperations(o_operation_list)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_all_operations'
        # # vba_code = """
        # # Public Function get_all_operations(robot_task)
        # #     Dim oOperationList (2)
        # #     robot_task.GetAllOperations oOperationList
        # #     get_all_operations = oOperationList
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'RobotTask(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import Iterator

from pycatia.space_analyses_interfaces.inertia import Inertia
from pycatia.system_interfaces.any_object import AnyObject
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class Inertias(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     Inertias
                | 
                | A collection of all inertia objects currently managed by the
                | application.
                | 
                | WARNING: this collection will be DEPRECATED in the next release. It is
                | recommended to use the method GetTechnologicalObject("Inertia") on the product
                | to analyze, to retrieve an Inertia object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=Inertia)
        self.inertias = com_object

    def add(self, i_object: AnyObject) -> Inertia:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func Add(AnyObject iObject) As Inertia
                | 
                |     Creates an Inertia object from an object and adds it to the Inertias
                |     collection.
                | 
                |     Parameters:
                | 
                |         iObject
                |             The Object 
                | 
                |     Returns:
                |         The created Inertia 
                |     Example:
                | 
                |              This example creates a new Inertia from a product
                |              TheProduct
                |             in the TheInertias collection.
                |
                |             Dim NewInertia As Inertia
                |             Set NewInertia = TheInertias.Add(TheProduct)

        :param AnyObject i_object:
        :rtype: Inertia
        """
        return Inertia(self.inertias.Add(i_object.com_object))

    def item(self, i_index: cat_variant) -> Inertia:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func Item(CATVariant iIndex) As Inertia
                | 
                |     Returns an Inertia object using its index or its name from the Inertias
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the Inertia to retrieve from the
                |             collection of inertias. As a numerics, this index is the rank of the Inertia in
                |             the collection. The index of the first Inertia in the collection is 1, and the
                |             index of the last Inertia is Count. As a string, it is the name you assigned to
                |             the Inertia. 
                | 
                |     Example:
                | 
                |              This example retrieves in ThisInertia the ninth
                |              Inertia,
                |             and in ThatInertia the Inertia named
                |             Inertia Of MyProduct from the TheInertias collection.
                |
                |             Dim ThisInertia As Inertia
                |             Set ThisInertia = TheInertias.Item(9)
                |             Dim ThatInertia As Inertia
                |             Set ThatInertia = TheInertias.Item("Inertia Of MyProduct")

        :param cat_variant i_index:
        :rtype: Inertia
        """
        return Inertia(self.inertias.Item(i_index))

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     Removes an Inertia object from the Inertias collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the Inertia to remove from the collection
                |             of inertias. As a numerics, this index is the rank of the Inertia in the
                |             collection. The index of the first Inertia in the collection is 1, and the
                |             index of the last Inertia is Count. As a string, it is the name you assigned to
                |             the Inertia. 
                | 
                |     Example:
                | 
                |              The following example removes the tenth Inertia and the Inertia
                |              named
                |             Inertia Of MyProduct from the TheInertias
                |             collection.
                |
                |             TheInertias.Remove(10)
                |             TheInertias.Remove("Inertia Of MyProduct")

        :param cat_variant i_index:
        :rtype: None
        """
        return self.inertias.Remove(i_index)

    def __getitem__(self, n: int) -> Inertia:
        if (n + 1) > self.count:
            raise StopIteration

        return Inertia(self.inertias.Item(n + 1))

    def __iter__(self) -> Iterator[Inertia]:
        for i in range(self.count):
            yield self.child_object(self.com_object.Item(i + 1))

    def __repr__(self):
        return f'Inertias(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class MhiRelationManagement(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MHIRelationManagement
                | 
                | Interface to access all supported relation types and a relation object's
                | atrribute provider to access it's attributes Role:
                | 
                | This interface, given a V5 process, product(or resource) object and the
                | relation type will get the handle to the relation object's attribute
                | provider.
                | 
                | This interface expect caller to use relation types defined in PPR Server which
                | can be obtained by the GetSupportedRelations method
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.mhi_relation_management = com_object

    def get_relation_object(self, i_relation_name: str, i_assigned_object: AnyObject) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRelationObject(CATBSTR iRelationName,
                | CATBaseDispatch iAssignedObject) As CATBaseDispatch
                | 
                |     This method provides handle to the E5 provider on the relation object that
                |     exists between selected activity and an item/resource
                | 
                |     Parameters:
                | 
                |         iRelationName
                |             Name of the relation existing between the selected activity and the
                |             item/resource The possible values for relation name can be obtained through a
                |             call to "DNBIAMHIRelationManagement#GetSupportedRelations" method
                |             
                |         iAssignedObject
                |             The item/resource that is related to the selected activity
                |             
                |         oRelationObjAttrProvider
                |             E5 provider on the relation object that exists between selected
                |             activity and an item/resource 
                | 
                |     Returns:
                |         S_OK or E_FAIL

        :param str i_relation_name:
        :param AnyObject i_assigned_object:
        :rtype: AnyObject
        """
        return self.mhi_relation_management.GetRelationObject(i_relation_name, i_assigned_object.com_object)

    def get_supported_relations(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetSupportedRelations() As CATSafeArrayVariant
                | 
                |     This method lists all the possible values that can passed as the relation
                |     name for "DNBIAMHIRelationManagement#GetRelationObject"
                |     method.
                | 
                |     Parameters:
                | 
                |         oListSupportedRelations
                |             The possible relation names can that are supported by the method
                |             GetRelationObject 
                | 
                |     Returns:
                |         S_OK or E_FAIL

        :rtype: tuple
        """
        return self.mhi_relation_management.GetSupportedRelations()

    def __repr__(self):
        return f'MhiRelationManagement(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dmaps_interfaces.resource import Resource
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class Resources(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     Resources
                | 
                | The collection of resources related to the current activity.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.resources = com_object

    def add(self, i_resource: Resource) -> Resource:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Add(Resource iResource) As Resource
                | 
                |     This method add the specified item in the current list
                | 
                |     Parameters:
                | 
                |         iItem
                |             The item to add 
                | 
                |     Returns:
                |         oitem The item

        :param Resource i_resource:
        :rtype: Resource
        """
        return Resource(self.resources.Add(i_resource.com_object))

    def add_by_assignment_type(self, i_resource: Resource, i_assignment_type: str) -> Resource:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddByAssignmentType(Resource iResource,
                | DNBResourceAssignmentType iAssignmentType) As Resource
                | 
                |     This method Assigns/Adds the specified resource with the specified
                |     assignment type
                | 
                |     Parameters:
                | 
                |         iResource
                |             The resource to be assigned 
                |         iAssignmentType
                |             Type of the Assignment (Resource to the Process). Only the
                |             following four types are supported at the moment: Process_Uses_Resource,
                |             Process_Runs_On_Resource, Process_Attaches_Resource, Process_Detaches_Resource
                |             
                | 
                |     Returns:
                |         oResource The resource when Add succeeds, unchanged otherwise

        :param Resource i_resource:
        :param str i_assignment_type:
        :rtype: Resource
        """
        return Resource(self.resources.AddByAssignmentType(i_resource.com_object, i_assignment_type))

    def item(self, i_index: cat_variant) -> Resource:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As Resource
                | 
                |     This method returns the idl object Resource for the specified resource
                |     identifier.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The resource identifier 
                | 
                |     Returns:
                |         oResource The idl resource

        :param cat_variant i_index:
        :rtype: Resource
        """
        return Resource(self.resources.Item(i_index))

    def remove_by_assignment_type(self, i_resource: Resource, i_assignment_type: str) -> Resource:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func RemoveByAssignmentType(Resource iResource,
                | DNBResourceAssignmentType iAssignmentType) As Resource
                | 
                |     This method Unassigns/Removes the specified resource if the assignement
                |     exists and is of the given type
                | 
                |     Parameters:
                | 
                |         iResource
                |             The resource to be Unassigned 
                |         iAssignmentType
                |             Type of the Assignment (Resource to the Process) to be removed
                |             
                | 
                |     Returns:
                |         oResource The resource when Remove succeeds, unchanged otherwise

        :param Resource i_resource:
        :param str i_assignment_type:
        :rtype: Resource
        """
        return Resource(self.resources.RemoveByAssignmentType(i_resource.com_object, i_assignment_type))

    def __repr__(self):
        return f'Resources(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class PCBComponent(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     PCBComponent

    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.pcb_component = com_object

    @property
    def capacitance(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CAPACITANCE() As CATBSTR
                | 
                |     Allow to get and set the CAPACITANCE Type of a component.
                | 
                |     Returns:
                | 
                |             The result of the method:
                |             S_OK if succeeded
                |             E_FAIL if failed

        :rtype: str
        """

        return self.pcb_component.CAPACITANCE

    @capacitance.setter
    def capacitance(self, value: str):
        """
        :param str value:
        """

        self.pcb_component.CAPACITANCE = value

    @property
    def power_opr(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property POWEROPR() As CATBSTR
                | 
                |     Allow to get and set the Operating power rating of a component The possible
                |     value are MECHANICAL or ELECTRICAL
                | 
                |     Returns:
                | 
                |             The result of the method:
                |             S_OK if succeeded
                |             E_FAIL if failed

        :rtype: str
        """

        return self.pcb_component.POWEROPR

    @power_opr.setter
    def power_opr(self, value: str):
        """
        :param str value:
        """

        self.pcb_component.POWEROPR = value

    @property
    def power_max(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property POWER_MAX() As CATBSTR
                | 
                |     Allow to get and set the POWER MAX of a component.
                | 
                |     Returns:
                | 
                |             The result of the method:
                |             S_OK if succeeded
                |             E_FAIL if failed

        :rtype: str
        """

        return self.pcb_component.POWER_MAX

    @power_max.setter
    def power_max(self, value: str):
        """
        :param str value:
        """

        self.pcb_component.POWER_MAX = value

    @property
    def package_number(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PackageNumber() As CATBSTR
                | 
                |     Allow to get and set the Package number of a component
                | 
                |     Returns:
                | 
                |             The result of the method:
                |             S_OK if succeeded
                |             E_FAIL if failed

        :rtype: str
        """

        return self.pcb_component.PackageNumber

    @package_number.setter
    def package_number(self, value: str):
        """
        :param str value:
        """

        self.pcb_component.PackageNumber = value

    @property
    def resistance(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property RESISTANCE() As CATBSTR
                | 
                |     Allow to get and set the RESISTANCE of a component.
                | 
                |     Returns:
                | 
                |             The result of the method:
                |             S_OK if succeeded
                |             E_FAIL if failed

        :rtype: str
        """

        return self.pcb_component.RESISTANCE

    @resistance.setter
    def resistance(self, value: str):
        """
        :param str value:
        """

        self.pcb_component.RESISTANCE = value

    @property
    def therm_cond(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property THERM_COND() As CATBSTR
                | 
                |     Allow to get and set the thermal conductivity of a
                |     component.
                | 
                |     Returns:
                | 
                |             The result of the method:
                |             S_OK if succeeded
                |             E_FAIL if failed

        :rtype: str
        """

        return self.pcb_component.THERM_COND

    @therm_cond.setter
    def therm_cond(self, value: str):
        """
        :param str value:
        """

        self.pcb_component.THERM_COND = value

    @property
    def theta_jb(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property THETA_JB() As CATBSTR
                | 
                |     Allow to get and set the junction to board thermal resistance of a
                |     component.
                | 
                |     Returns:
                | 
                |             The result of the method:
                |             S_OK if succeeded
                |             E_FAIL if failed

        :rtype: str
        """

        return self.pcb_component.THETA_JB

    @theta_jb.setter
    def theta_jb(self, value: str):
        """
        :param str value:
        """

        self.pcb_component.THETA_JB = value

    @property
    def theta_jc(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property THETA_JC() As CATBSTR
                | 
                |     Allow to get and set the junction to case thermal resistance of a
                |     component.
                | 
                |     Returns:
                | 
                |             The result of the method:
                |             S_OK if succeeded
                |             E_FAIL if failed

        :rtype: str
        """

        return self.pcb_component.THETA_JC

    @theta_jc.setter
    def theta_jc(self, value: str):
        """
        :param str value:
        """

        self.pcb_component.THETA_JC = value

    @property
    def tolerance(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TOLERANCE() As CATBSTR
                | 
                |     Allow to get and set the TOLERANCE of a component.
                | 
                |     Returns:
                | 
                |             The result of the method:
                |             S_OK if succeeded
                |             E_FAIL if failed

        :rtype: str
        """

        return self.pcb_component.TOLERANCE

    @tolerance.setter
    def tolerance(self, value: str):
        """
        :param str value:
        """

        self.pcb_component.TOLERANCE = value

    def __repr__(self):
        return f'PCBComponent(name="{self.name}")'
